
# -*- coding: utf-8 -*-
import re
import sys

from pypeit.scripts.chk_for_calibs import ChkForCalibs

if __name__ == '__main__':
    sys.argv[0] = re.sub(r'(-script\.pyw?|\.exe)?$', '', sys.argv[0])
    sys.exit(ChkForCalibs.entry_point())
